# dictforge

Создавайте словари для Kindle на любом языке.

## Быстрый старт

[Установите утилиту](installation.md)

```bash
dictforge --kindlegen-path "/Applications/Kindle Previewer 3.app/Contents/lib/fc/bin/kindlegen" sr en
```

- При первом запуске dictforge скачивает дамп Викисловаря (≈20 ГБ в сжатом виде); последующие запуски используют его повторно.
- Пример команды собирает сербско-хорватский → английский словарь в каталоге `build/`.
- Скопируйте полученный MOBI-файл в `Documents/Dictionaries/` на Kindle либо в `Documents/`, если каталога `Dictionaries` нет.
- Во время чтения зажмите слово, чтобы открыть словарь. Поскольку Kindle не поддерживает некоторые языки, например сербский,
  при первом использовании выберите словарь вручную через `Dictionary` → `Select new dictionary`.

### Как привязать словарь на Kindle

Kindle автоматически подбирает словарь по языку книги, записанному в метаданных.

К сожалению, Kindle имеет очень ограниченный список языков для которых можно создать словарь:
[Список поддерживаемых Kindle языков](https://wiki.mobileread.com/wiki/Amazon_Kindle#Supported_languages).

Вместо неподдерживаемого языка выберите любой (не нужный вам) поддерживаемый язык как в опции `--kindle-lang` так и (желательно) для книг, и словарь будет подключаться сам.

Если вы используете [Calibre](https://calibre-ebook.com/) то выберите этот язык до конвертации книги в формат MOBI.
